@@ -16,6 +16,8 @@ from datetime import datetime
 import pytz
 from social_django.models import UserSocialAuth
 
+from urllib.parse import urlencode
+
 from .constants import BACKEND_NAME
 from . import helpers
 
@@ -30,6 +32,26 @@ def request_password_reset(email):
     return http_response
 
 
+def get_logout_url(post_logout_redirect_uri):
+    """
+    Get Tahoe IdP URL.
+    """
+    tenant_id = helpers.get_tenant_id()
+    client_configs = helpers.get_key_and_secret()
+    base_url = helpers.get_idp_base_url()
+
+    query_params = (
+        ('tenantId', tenant_id),
+        ('client_id', client_configs['key']),
+        ('post_logout_redirect_uri', post_logout_redirect_uri),
+    )
+
+    return '{base}/oauth2/logout?{query}'.format(
+        base=base_url,
+        query=urlencode(query_params),
+    )
+
+
 def get_tahoe_idp_id_by_user(user):
     """
     Get Tahoe IdP unique ID for a Django user.
